// Copyright 2021 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


import UIKit

import ArcGIS


@UIApplicationMain

class AppDelegate: UIResponder, UIApplicationDelegate {

    var window: UIWindow?

    func application(_ application: UIApplication,
                     didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {

        setupOAuthManager()

        return true
    }

}

// MARK: - OAuth
extension AppDelegate {
    private func setupOAuthManager() {
        // Initialize OAuth configuration with client ID and redirect URL.
        let config = AGSOAuthConfiguration(portalURL: nil,
                                           clientID: .clientID,
                                           redirectURL: .redirectURL)
        // Add OAuth configuration to authentication manager.
        AGSAuthenticationManager.shared()
            .oAuthConfigurations
            .add(config)
        // Enable auto-sync to keychain on the auth manager's credential cache.
        AGSAuthenticationManager.shared()
            .credentialCache
            .enableAutoSyncToKeychain(withIdentifier: .keychainIdentifier,
                                      accessGroup: nil,
                                      acrossDevices: false)
    }
}


